@@ -652,22 +652,17 @@ class PhIDEBase(object):
                 elif args_list.index(arg) % 2 == 1:
                     values.append(arg)
             args = zip(keys, values)
-            logger.debug(job_args)
-            print(job_args)
+
             args_dict = dict(args)
             # 获取生成dict中的参数, 将传进来的dict进行替换
             for key in args_dict.keys():
                 if key.lstrip('--') in job_args.keys():
                     args_dict[key] = job_args[key.lstrip('--')]
 
-            logger.debug(args_dict)
-            print(args_dict)
             new_key = []
             for args_key in args_dict.keys():
                 new_key.append(args_key.lstrip('--'))
             new_args = dict(zip(new_key, args_dict.values()))
-            logger.debug(new_args)
-            print(new_args)
             return new_args
 
         def ast_parse(string):
@@ -775,6 +770,9 @@ class PhIDEBase(object):
         while execution_response:
             time.sleep(60)
             if len(execution_response['executions']) == 0:
+                execution_response = step_client.list_executions(
+                    stateMachineArn=step_create_response['stateMachineArn'],
+                )
                 continue
 
             execution_response = step_client.list_executions(
